# -*- coding: utf-8 -*- 
'''
Module: num2word_PL.py
Requires: num2word_PL.py
Version: 0.1

Author:
   Sebastian Żurek (sebzur@gmail.com)
   Maciej Sznajder (maciejsznajder@gmail.com)
   
Copyright:
    Copyright (c) 2007, Sebastian Żurek.  All Rights Reserved.
    Copyright (c) 2008, Maciej Sznajder.  All Rights Reserved.

Licence:
    This module is distributed under the Lesser General Public Licence.
    http://www.opensource.org/licenses/lgpl-license.php

Data from:
    http://www.uni-bonn.de/~manfear/large.php
    
Usage:
    from num2word_PL import n2w, to_card, to_ord, to_ordnum
    to_card(1234567890)
    n2w.is_title = True
    to_card(1234567890)
    to_ord(1234567890)
    to_ordnum(1234567890)
    to_year(1976)
    to_currency(dollars*100 + cents, longval=False)
    to_currency((dollars, cents))
    

History:

    1.3.2 : new method full_numbers(), it solved problem with ord big numbers
    
    1.3.1 : new to_ordinal() method, it turns right words but ther are some problems
    with exceptions like f.e.: 1e3 or 1e6;
    Fixed problem with word "tysiąc" in some numbers -> merge method;
    
    1.2   : to_ordinal_num() made shorter and simpler (but slower)
    strings in merge() now interpolated
    to_year() and to_currency() added
         
    1.1   : to_ordinal_num() fixed for 11,12,13   
'''
from __future__ import division 
import num2word_EU

    
class Num2Word_PL(num2word_EU.Num2Word_EU):

    def set_high_numwords(self, high):
        max = 3 + 3*len(high)
        for word, n in zip(high, range(max, 3, -3)):
            self.cards[10**n] = word + "ilion"

    def setup(self):
        self.negword = "minus "
        self.pointword = "kropka"
        self.errmsg_nonnum = "Only numbers may be converted to words."
        self.exclude_title = ["and", "point", "minus"]

        self.mid_numwords = [(1000, "tysiąc"), (100, "sto"), 
                             (90, "dziewięćdziesiąt"), (80, "osiemdziesiąt"), (70, "siedemdziesiąt"),
                             (60, "sześćdziesiąt"), (50, "pięćdziesiąt"), (40, "czterdzieści"),
                             (30, "trzydzieści")]

        self.low_numwords = ["dwadzieścia", "dziewiętnaście", "osiemnaście", "siedemnaście",
                             "szesnaście", "piętnaście", "czternaście", "trzynaście",
                             "dwanaście", "jedenaście", "dziesięć", "dziewięć", "osiem",
                             "siedem", "sześć", "pięć", "cztery", "trzy", "dwa",
                             "jeden", "zero"]
        
        self.ords = { "jeden"      : "pierwszy",
                      "dwa"        : "drugi",
                      "trzy"       : "trzeci",
                      "cztery"     : "czwarty",
                      "pięć"       : "piąty",
                      "sześć"      : "szósty",
                      "siedem"     : "siódmy",
                      "osiem"      : "ósmy",
                      "dziewięć"   : "dziewiąty",
                      "dziesięć"   : "dziesiąty",
                      "dwanaście"  : "dwunasty",
                      "dwadzieścia": "dwudziesty",
                      "sto"        : "setny",
                      "dwieście"   : "dwusetny",
                      "trzysta"    : "trzysetny",
                      "czterysta"  : "czterechsetny" }
        
        
        self.ords_next_lo_last = {"dwadzieścia" : "dwudziesty"}

        self.full_exceptions = {"jeden"  : "tysięczny",
                                "dwa"    : "dwutysięczny",
                                "trzy"   : "trzytysięczny",
                                "cztery" : "czterotysięczny",
                                "siedem" : "siedmiotysięczny",
                                "osiem"  : "ośmiotysieczny"}
        
        
    def merge(self, curr, next):
        ctext, cnum, ntext, nnum = curr + next
        
        if cnum == 1 and nnum < 100:
            return next
        elif 100 > cnum > nnum :
            return ("%s %s"%(ctext, ntext), cnum + nnum)
        elif cnum >= 100 > nnum:
            return ("%s  %s"%(ctext, ntext), cnum + nnum)            
        elif nnum > cnum:            
            if nnum<1000:
                if cnum<2 :
                    return ("%s"%(ntext), cnum * nnum)            
                elif cnum<3:
                    return ("%s"%('dwieście'), cnum * nnum)            
                elif cnum<5:
                    return ("%s%s"%(ctext,'sta'), cnum * nnum)            
                elif cnum<10:
                    return ("%s%s"%(ctext,'set'), cnum * nnum)                                 

        if cnum+nnum>1000:
            #print unicode(ctext,'utf-8').encode('iso-8859-2'), cnum, unicode(ntext,'utf-8').encode('iso-8859-2'), nnum
            if cnum*nnum<2000 :
                return ("%s %s"%(ctext, ntext), cnum * nnum)
            elif cnum*nnum<5000 :
                return ("%s %s"%(ctext, ntext+'e'), cnum * nnum)
            
        if curr[1]<1000 and cnum*nnum>=5000 :
            i,j=0,0
            ctext_new,ntext_new='','' 
            for word in ctext.split():
                i+=1
                if word=='tysi\xc4\x85c':
                    ctext_new+=' tysięcy'
                elif word!='tysi\xc4\x85c':
                    ctext_new+=' '+ctext.split()[i-1]

            for word in ntext.split():
                j+=1
                if word=='tysi\xc4\x85c':
                    ntext_new+=' tysięcy'
                elif word!='tysi\xc4\x85c':
                    ntext_new+=' '+ntext.split()[j-1]

            ctext,ntext=ctext_new,ntext_new
                        
        return ("%s %s"%(ctext, ntext), cnum * nnum)

#-------------------------------------------------
    def to_ordinal(self, value):
        outwords = self.to_cardinal(value).split()
 
        self.last_number(outwords)
        self.next_to_last_number(outwords)
        
        # "if" condition solve problem with small numbers. Method full_numbers dosn't do anything with values<1000 so it broke ord word in method n2w.test()

        if value>=1000:
            self.full_numbers(outwords,value)        
        
        return " ".join(outwords)

    def last_number(self,outwords):
        lastwords = outwords[-1].split("-")
        lastword = lastwords[-1].lower()
            
        try:
            lastword = self.ords[lastword]
        except KeyError:
            if lastword[-1] == "e" or "a" and lastword[-2] == "i":
                lastword=lastword[:-5]+"sty"
            if lastword[-1] == "i" and lastword[-2] == "c":
                 lastword=lastword[:-4]+"sty"
            if lastword[-1] == "t" and lastword[-2] == "e":
                lastword+="ny"
            if lastword[-1] == "y" and lastword[-2] == "c":
                lastword=lastword[:-1]+"zny"
            if lastword[-1] == "n" and lastword[-2] == "o":
                lastword+="owy"
            if lastword[-1] == "t":
                lastword+="y"
            if lastword[-1] == "e":
                lastword=lastword[:-3]+"ty"
        
        lastwords[-1] = self.title(lastword)
        outwords[-1] = "-".join(lastwords)
        
    def next_to_last_number(self,outwords):
        if len(outwords)>1:
            losts=outwords[-2].split("-")
            lost=losts[-1].lower()
         
            try:
                lost = self.ords_next_lo_last[lost]
            except KeyError:
                if lost[-1] == "t":
                    lost+="y"
                if lost[-1] == "i" and lost[-2] == "c":
                    lost = lost[:-4]+"sty"
                if lost[-1] == "a" and lost[-2] == "i":
                    lost=lost[:-3]+"sty"
                if lost[-1] == "o":
                    lost=lost
        
            losts[-1] = self.title(lost)
            outwords[-2] = "-".join(losts)

    def full_numbers(self,outwords,value):

        #values > 1000
        
        fulls=outwords[-2].split("-")
        full=fulls[-1].lower()

        lasts=outwords[-1].split("-")
        last=lasts[-1].lower()

        firsts=outwords[0].split("-")
        first=firsts[0].lower()

        try:
            full = self.full_exceptions[full]
            outwords[-1] = ""
        except KeyError:
            if first == "jeden":
                outwords[0] = ""
            if full == "szósta" and last == "szósty":
                outwords[-2] = last
                outwords[-1] = ""
            if full[-1] == "\x87": #\x87 -> ć
                full = full[:-2]+"cio"
            if full[-1] == "o" or "e" and value/1000<19:
                full = full + " " + last
                outwords[-1]=""
            if full[-2] == "t" and full[-3] == "s" and last[-1] == "y" and value>10000:
                full = full[:-1] + "a " + last
                outwords[-1]=""
            if full[-3] == "\x85" and value>10000:
                full = full[:-4] + "ęcio " + last
                outwords[-1]=""
                      
        fulls[-1] = self.title(full)
        outwords[-2] = "-".join(fulls)
#------------------------------------------------

    def to_ordinal_num(self, value):
        self.verify_ordinal(value)
        return "%s%s"%(value, self.to_ordinal(value)[-2:])


    def to_year(self, val, longval=True):
        if not (val//100)%10:
            return self.to_cardinal(val)
        return self.to_splitnum(val, hightxt="hundred", jointxt="and",
                                longval=longval)

    def to_currency(self, val, longval=True):
        return self.to_splitnum(val, hightxt="zł", lowtxt="gr",
                                jointxt="i", longval=longval)

class Test:
    def test(self,MainTest,Currency,Date,min,max,step):
        
        n2w = Num2Word_PL()
        to_card = n2w.to_cardinal
        to_ord = n2w.to_ordinal
        to_ordnum = n2w.to_ordinal_num
        to_year = n2w.to_year
        
        for val in range(min,max,step):
            if MainTest == 1:
                n2w.test(val)
            if Currency == 1:
                print n2w.to_currency(val)
            if Date == 1:
                print n2w.to_year(val)

